Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1532)

Unified Diff: content/public/browser/notification_types.h

Issue 10837296: Fix a bug where the inspector would not keep event pages alive. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: yurys Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/debugger/worker_devtools_manager.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/notification_types.h
diff --git a/content/public/browser/notification_types.h b/content/public/browser/notification_types.h
index a1122503301bea28ecd535a300a7ed0dc6252074..b2a162f766bc518ef775ec12373efa8f6103c82b 100644
--- a/content/public/browser/notification_types.h
+++ b/content/public/browser/notification_types.h
@@ -163,13 +163,13 @@ enum NotificationType {
// Devtools ------------------------------------------------------------------
- // Indicates that a devtools window is opening. The source is the
- // BrowserContext* and the details is the inspected RenderViewHost*.
- NOTIFICATION_DEVTOOLS_WINDOW_OPENING,
+ // Indicates that a devtools agent has attached to a client. The source is
+ // the BrowserContext* and the details is the inspected RenderViewHost*.
+ NOTIFICATION_DEVTOOLS_AGENT_ATTACHED,
- // Indicates that a devtools window is closing. The source is the
- // BrowserContext* and the details is the inspected RenderViewHost*.
- NOTIFICATION_DEVTOOLS_WINDOW_CLOSING,
+ // Indicates that a devtools agent has detached from a client. The source is
+ // the BrowserContext* and the details is the inspected RenderViewHost*.
+ NOTIFICATION_DEVTOOLS_AGENT_DETACHED,
// WebContents ---------------------------------------------------------------
« no previous file with comments | « content/browser/debugger/worker_devtools_manager.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698